Esprima: Speed Comparisons

### Speed Comparison keeps everything in perspective

Please wait...

Warning: Since each parser may have a different format for the syntax tree, the speed is not fully comparable (the cost of constructing different result is obviously varying). These tests exist only to ensure that Esprima parser is not ridiculously slow compare to other parsers.

More comparison variants will be added in the near future.

Esprima version: .

parse-js is the parser used in UglifyJS v1. It's a JavaScript port of the Common LISP version. This test uses `parse-js` from UglifyJS version 1.3.2 (June 26 2012).

Acorn is a compact stand-alone JavaScript parser. This test uses Acorn revision 48bbcd94 (dated Oct 19 2012).

Time measurement is carried out using Benchmark.js.

Esprima is created and mantained by Ariya Hidayat.

- @Esprima
- GitHub